#
# spec file for package python-pyudev
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pyudev
Version:        0.24.3
Release:        1.1
Summary:        Udev bindings for Python
License:        LGPL-2.1-or-later
URL:            https://pyudev.readthedocs.io/
Source0:        https://github.com/pyudev/pyudev/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}-gh.tar.gz
# PATCH-FIX-UPSTREAM pytest_register_mark.patch gh#pyudev/pyudev#404 mcepl@suse.com
# Add missing mark registration and register and use another mark
Patch0:         pytest_register_mark.patch
# PATCH-FIX-OPENSUSE hypothesis_settings.patch mcepl@suse.com
# tests timeout on OBS
Patch2:         hypothesis_settings.patch
# PATCH-FIX-UPSTREAM gh#pyudev/pyudev#512
Patch3:         support-pytest-8.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(udev)
Requires:       libudev1
BuildArch:      noarch
BuildRequires:  %{python_module Sphinx}
BuildRequires:  %{python_module docutils}
BuildRequires:  %{python_module hypothesis}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module yapf}
%if 0%{?suse_version} < 1550
BuildRequires:  python-mock
%endif
%ifpython2
# pyudev was last used in KDE:Unstable:Playground (pyudev-0.8)
Provides:       pyudev = %{version}
Obsoletes:      pyudev < %{version}
%endif
%python_subpackages

%description
A Python binding to libudev, the hardware management library and service found
in modern linux systems.

%prep
%autosetup -p1 -n pyudev-%{version}

# Disable intersphinx and issuetracker, we don't want to access the web during doc build:
sed -i -e "s|'sphinx.ext.intersphinx',\\?||" -e "s|'sphinxcontrib.issuetracker',\\?||" doc/conf.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# We don't have real /dev in osc build chroot gh#pyudev/pyudev#404
# ... or apparently, a reliable testsuite gh#pyudev/pyudev#457
%pytest -k 'not (real_udev or test_as or test_getitem)'

%files %{python_files}
%license COPYING
%doc CHANGES.rst README.rst
%{python_sitelib}/pyudev
%{python_sitelib}/pyudev-%{version}.dist-info

%changelog
* Wed May 15 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.24.3:
  * Tidies and Maintenance fixes
- Switch to pyproject macros.
- No more greedy globs in %%files.
- Add patch support-pytest-8.patch:
  * Support pytest 8 changes.
* Mon Oct 30 2023 Daniel Garcia <daniel.garcia@suse.com>
- update hypothesis_settings.patch:
  * Extend deadline for test_child_of_parents that fails on ppc64le (bsc#1216607)
* Wed May  3 2023 Dirk Müller <dmueller@suse.com>
- update to 0.24.1:
  * Recommended development release: Fedora 37
  * Add support for PySide6
  * Add missing 'priority' argument for GLib.to_add_watch()
  * Tidies and Maintenance fixes
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Fri Oct 14 2022 Dirk Müller <dmueller@suse.com>
- update hypothesis_settings.patch:
  * extend deadlines to handle qemu emulated arches better
* Sat Oct  1 2022 Dirk Müller <dmueller@suse.com>
- update to 0.24.0:
  * Remove six dependency
  * Drop pylint tasks
  * Support python 3.9 and 3.10
* Thu Mar 17 2022 Steve Kowalik <steven.kowalik@suse.com>
- Skip some unreliable tests.
* Thu Mar 10 2022 mcepl@cepl.eu
- Update to version 0.23.2+14:
  * Remove a bunch of python-2 only testing
  * Bump some Python versions
  * Get rid of six dependency
  * Drop all pylint tasks
  * Remove overly rigorous tests
  * Make a package target that uses build
  * Omit PyPy flakey test
  * Check whether the Context has a "_libudev" attribute
  * Remove setup.cfg
  * Remove obsolete egg_info parameter
  * Delete another flaky test
- Rebase hypothesis_settings.patch and pytest_register_mark.patch.
- Drop six (Build)?Requires.
* Tue Jan 25 2022 Bernhard Wiedemann <bwiedemann@suse.com>
- Don't add date to version for reproducible builds (boo#1047218)
* Sun Jan 16 2022 mcepl@cepl.eu
- Update to version 0.22.0+git.1642212208.d5630bf (bsc#1194613):
  * Remove another flakey test
  * Remove all traces of tox
  * Update next Fedora to 35
  * Delete a test which is probably flakey for real
  * Bump recommended development environment to fedora 34
  * Use yamllint on all the configuration files
  * Add annotations to GitHub workflows
  * No longer use --recursive for isort
  * Update formatting for new black
  * Establish a weekly task for future fedora
- Remove upstreamed patches:
  - remove_mock.patch
* Tue Aug 10 2021 Matej Cepl <mcepl@suse.com>
- Add hypothesis_settings.patch to allow longer timeouts in OBS.
* Sat Dec 12 2020 Benjamin Greiner <code@bnavigator.de>
- Add remove_mock.patch gh#pyudev/pyudev#409
- Static linting with pylint is not needed for unit tests or build
* Thu Oct  8 2020 Matej Cepl <mcepl@suse.com>
- Add pytest_register_mark.patch to make the test suite at least
  syntactically correct and skip over tests we cannot run because
  of missing /dev gh#pyudev/pyudev#404.
* Fri Feb 28 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.22.0:
  - Add a six-enabled move for collections move imports:
    https://github.com/pyudev/pyudev/pull/386
  - Fix any newly introduced pylint errors
  - Numerous improvements or updates to the test infrastructure
  - A number of test updates
  - Require yapf 0.21.0 for Python formatting
  - Various documentation fixes and updates
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Tue Jan 30 2018 mimi.vx@gmail.com
- fix Requires and BuiildRequires
* Tue Jan 23 2018 tbechtold@suse.com
- Require libudev (bsc#1077282)
  Otherwise, an pyudev import fails with:
  ImportError: No library named udev
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Mon May 23 2016 tbechtold@suse.com
- Remove do_not_install_tests.patch
- Require python-six
* Mon May 23 2016 tbechtold@suse.com
- update to 0.20.0:
  * Remove parsing code added in previous release.
  * No longer do CI for Python 2.6.
  * Eliminate all wildcard imports and __all__ statements.
  * No longer use deprecated Device.from_sys_path() method.
  * Minor pylint induced changes.
  * Documentation fixes.
  * Restore raising KeyError by Attributes.as* methods when attribute not found.
  * Explicitly require six module.
  * Never raise a DeviceNotFoundError when iterating over a device enumeration.
  * Device.subsystem() now returns None if device has no subsystem.
  * Add DeprecationWarnings to deprecated Device methods.
  * Replace "/" with "!" in Device.from_name() sys_name parameter.
  * Add some unstable classes for parsing some kinds of values.
  * Make version info more like Python's including micro numbers and levels.
  * Refactor some internal modules into subdirectories.
  * Work on tests and reproducers.
  * DeviceNotFoundError is no longer a subtype of LookupError
  * Added support for pyqt5 monitor observer
  * Added discover module, which looks up a device on limited information
  * Attributes class no longer extends Mapping, extends object instead
  * Attributes class no longer inherits [] operator, Mapping methods
  * Attributes class objects are no longer iterable
  * Attributes.available_attributes property added
  * Attributes.get() method, with usual semantics, defined
  * Device.from_* methods are deprecated, uses Devices.from_* methods instead
  * Device.from_device_file() now raises DeviceNotFoundByFileError
  * Device.from_device_number() now raises DeviceNotFoundByNumberError
  * Devices.from_interface_index() method added
  * Devices.from_kernel_device() method added
  * Numerous testing infrastructure changes
- Remove do_not_install_tests.patch . No longer needed.
- Require libudev1 . Needed to use python-pyudev
* Wed Sep 23 2015 asterios.dramis@gmail.com
- Added a patch (do_not_install_tests.patch) to not install the
  tests as a module (not needed). Fixes also file conflicts in
  Factory.
* Tue Sep 15 2015 hpj@urpla.net
- Update to version 0.17:
  * #52: Remove global libudev object
  * #57: Really start the monitor on :meth:`pyudev.Monitor.poll()`
  * #60: Do not use :meth:`select.select` to avoid hitting its file descriptor
    limit
  * #58: Force non-blocking IO in :class:`pyudev.Monitor` to avoid blocking on
    receiving the device
  * #63: Set proper flags on pipe fds.
  * #65: Handle irregular polling events properly.
  * #50: Add :class:`pyudev.wx.MonitorObserver` and deprecate
    :class:`pyudev.wx.WxUDevMonitorObserver`
  * #50: Add :class:`pyudev.glib.MonitorObserver` and deprecate
    :class:`pyudev.glib.GUDevMonitorObserver`
  * #50: Add :class:`pyudev.pyqt4.MonitorObserver` and deprecate
    :class:`pyudev.pyqt4.QUDevMonitorObserver`
  * #50: Add :class:`pyudev.pyside.MonitorObserver` and deprecate
    :class:`pyudev.pyside.QUDevMonitorObserver`
  * Add a wrapper function to retry interruptible system calls.
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Tue Nov 20 2012 saschpe@suse.de
- Build HTML documentation
- Fix SLE_11_SP2 build (not noarch)
* Sun Nov 18 2012 asterios.dramis@gmail.com
- Update to version 0.16.1:
  * #53: Fix source distribution
  * #54: Fix typo in test
  From version 0.16:
  * Remove :meth:`pyudev.Monitor.from_socket`.
  * Deprecate :meth:`pyudev.Device.traverse()` in favor of
    :attr:`pyudev.Device.ancestors`.
  * #47: Deprecate :meth:`pyudev.Monitor.receive_device` in favor of
    :attr:`pyudev.Monitor.poll`.
  * #47: Deprecate :attr:`pyudev.Monitor.enable_receiving` in favor of
    :attr:`pyudev.Monitor.start`.
  * #47: Deprecate :attr:`pyudev.Monitor.__iter__` in favor of explicit looping
    or :class:`pyudev.MonitorObserver`.
  * #49: Deprecate ``event_handler`` to :class:`pyudev.MonitorObserver` in
    favour of ``callback`` argument.
  * #46: Continuously test pyudev on Travis-CI.
  * Add :attr:`pyudev.Device.ancestors`.
  * Add :attr:`pyudev.Device.action`.
  * #10: Add :attr:`pyudev.Device.sequence_number`.
  * #47: Add :meth:`pyudev.Monitor.poll`.
  * #47: Add :attr:`pyudev.Monitor.started`.
  * #49: Add ``callback`` argument to :class:`pyudev.Monitor`.
  * :meth:`pyudev.Monitor.start` can be called repeatedly.
  * #45: Get rid of 2to3
  * #43: Fix test failures on Python 2.6
  * Fix signature in declaration of ``udev_monitor_set_receive_buffer_size``.
  * #44: Test wrapped signatures with help of ``gccxml``.
  * Fix compatibility with udev 183 and newer in :class:`pyudev.Context`.
  * :meth:`pyudev.MonitorObserver.stop` can be called from the observer thread.
- Removed python-setuptools and added python-distribute as build requirement.
* Sat Mar 10 2012 asterios.dramis@gmail.com
- Update to version 0.15:
  * #20: :meth:`pyudev.Monitor.filter_by()` and
    :meth:`pyudev.Monitor.filter_by_tag()` can be called after
    :meth:`pyudev.Monitor.enable_receiving()` now
  * #20: Added :meth:`~pyudev.Monitor.remove_filter()`
  * :class:`pyudev.MonitorObserver` calls
    :meth:`pyudev.Monitor.enable_receiving()` now when started.
  * #40: Added user guide to the documentation
  * #39: Added :meth:`pyudev.Device.from_device_file()`
  * :data:`errno.EINVAL` from underlying libudev functions causes
    :exc:`~exceptions.ValueError` instead of
    :exc:`~exceptions.EnvironmentError` now.
* Sat Feb 18 2012 asterios.dramis@gmail.com
- Update to version 0.14:
  * Documentation now hosted at http://pyudev.readthedocs.org
  * #37: Added :class:`pyudev.wx.WxUDevMonitorObserver` for wxPython
  * Added :class:`pyudev.MonitorObserver`
  * Added :attr:`pyudev.glib.GUDevMonitorObserver.enabled`,
    :attr:`pyudev.pyqt4.QUDevMonitorObserver.enabled` and
    :attr:`pyudev.pyside.QUDevMonitorObserver.enabled`
* Sun Nov  6 2011 asterios.dramis@gmail.com
- Update to version 0.13:
  * #36: Added :meth:`pyudev.Monitor.set_receive_buffer_size` (thanks to Rémi
    Rérolle)
  * #34: :class:`pyudev.Device.tags` returns a :class:`pyudev.Tags` object now
  * Added :meth:`pyudev.Enumerator.match_parent`
  * Added ``parent`` keyword argument to :meth:`pyudev.Enumerator.match()`
  * Removed :meth:`pyudev.Enumerator.match_children` in favour of
    :meth:`pyudev.Enumerator.match_parent`
  * :attr:`pyudev.Device.children` requires udev version 172 now
  * #31: Added :meth:`pyudev.Enumerator.match_attribute`
  * Added ``nomatch`` argument to :meth:`pyudev.Enumerator.match_subsystem` and
    :meth:`pyudev.Enumerator.match_attribute`
* Wed Aug 31 2011 asterios.dramis@gmail.com
- Update to version 0.12:
  * #32: Fixed memory leak
  * #33: Fixed Python 3 support for :mod:`pyudev.glib`
  * Fixed license header in :mod:`pyudev._compat`
- Spec file updates.
  * Changed License: to LGPL-2.1+.
  * Minor other updates.
* Sun Aug 28 2011 asterios.dramis@gmail.com
- Update to version 0.11:
  * #30: Added :attr:`pyudev.Device.sys_number`
  * #29: Added :meth:`pyudev.Device.from_device_number` and
    :attr:`pyudev.Device.device_number`
  * Officially support PyPy now
  From 0.10:
  * Added :attr:`pyudev.__version_info__`
  * Added :attr:`pyudev.Device.device_type`
  * :class:`pyudev.Context`, :class:`pyudev.Enumerator`, :class:`pyudev.Device`
    and :class:`pyudev.Monitor` can now directly be passed to
    :mod:`ctypes`-wrapped functions
  * #24: Added :attr:`pyudev.Context.run_path`
  From 0.9:
  * #21: Added :meth:`pyudev.Device.find_parent`
  * #22: Added :meth:`pyudev.Monitor.filter_by_tag`
  * Added :attr:`pyudev.Context.log_priority` to control internal UDev logging
  * Improve error reporting, if libudev is missing
- Spec file updates:
  * Changed package name to python-pyudev.
  * Changed License: to LGPL-2.1.
  * Updated Url:.
  * Added Provides/Obsoletes entries for pyudev.
  * Build the package as noarch.
  * Minor other updates.
* Tue Feb  8 2011 tittiatcoke@gmail.com
- Initial Package (version 0.8).
